Class: Google::Apis::GkeonpremV1::ListVmwareAdminClustersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb

Overview

Response message for listing VMware admin clusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListVmwareAdminClustersResponse

Returns a new instance of ListVmwareAdminClustersResponse.



2922
2923
2924
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 2922

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token identifying a page of results the server should return. If the token is not empty this means that more results are available and should be retrieved by repeating the request with the provided page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2910
2911
2912
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 2910

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2915
2916
2917
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 2915

def unreachable
  @unreachable
end

#vmware_admin_clustersArray<Google::Apis::GkeonpremV1::VmwareAdminCluster>

The list of VMware admin cluster. Corresponds to the JSON property vmwareAdminClusters



2920
2921
2922
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 2920

def vmware_admin_clusters
  @vmware_admin_clusters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2927
2928
2929
2930
2931
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 2927

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
  @vmware_admin_clusters = args[:vmware_admin_clusters] if args.key?(:vmware_admin_clusters)
end