Class: Google::Apis::GkeonpremV1::NodeTaint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb

Overview

NodeTaint applied to every Kubernetes node in a node pool. Kubernetes taints can be used together with tolerations to control how workloads are scheduled to your nodes. Node taints are permanent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTaint

Returns a new instance of NodeTaint.



3104
3105
3106
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3104

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effectString

The taint effect. Corresponds to the JSON property effect

Returns:

  • (String)


3092
3093
3094
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3092

def effect
  @effect
end

#keyString

Key associated with the effect. Corresponds to the JSON property key

Returns:

  • (String)


3097
3098
3099
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3097

def key
  @key
end

#valueString

Value associated with the effect. Corresponds to the JSON property value

Returns:

  • (String)


3102
3103
3104
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3102

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3109
3110
3111
3112
3113
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3109

def update!(**args)
  @effect = args[:effect] if args.key?(:effect)
  @key = args[:key] if args.key?(:key)
  @value = args[:value] if args.key?(:value)
end