Class: Google::Apis::GkeonpremV1::ResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::GkeonpremV1::ResourceStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb
Overview
ResourceStatus describes why a cluster or node pool has a certain status. (e.g. , ERROR or DEGRADED).
Instance Attribute Summary collapse
-
#conditions ⇒ Array<Google::Apis::GkeonpremV1::ResourceCondition>
ResourceCondition provide a standard mechanism for higher-level status reporting from controller.
-
#error_message ⇒ String
Human-friendly representation of the error message from controller.
-
#version ⇒ String
Reflect current version of the resource.
-
#versions ⇒ Google::Apis::GkeonpremV1::Versions
Versions describes the mapping of a given version to the number of machines under this version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatus
constructor
A new instance of ResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatus
Returns a new instance of ResourceStatus.
3542 3543 3544 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3542 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Array<Google::Apis::GkeonpremV1::ResourceCondition>
ResourceCondition provide a standard mechanism for higher-level status
reporting from controller.
Corresponds to the JSON property conditions
3520 3521 3522 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3520 def conditions @conditions end |
#error_message ⇒ String
Human-friendly representation of the error message from controller. The error
message can be temporary as the controller controller creates a cluster or
node pool. If the error message persists for a longer period of time, it can
be used to surface error message to indicate real problems requiring user
intervention.
Corresponds to the JSON property errorMessage
3529 3530 3531 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3529 def @error_message end |
#version ⇒ String
Reflect current version of the resource.
Corresponds to the JSON property version
3534 3535 3536 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3534 def version @version end |
#versions ⇒ Google::Apis::GkeonpremV1::Versions
Versions describes the mapping of a given version to the number of machines
under this version.
Corresponds to the JSON property versions
3540 3541 3542 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3540 def versions @versions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3547 3548 3549 3550 3551 3552 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3547 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @error_message = args[:error_message] if args.key?(:error_message) @version = args[:version] if args.key?(:version) @versions = args[:versions] if args.key?(:versions) end |