Class: Google::Apis::GkeonpremV1::VmwareAdminCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb

Overview

Resource that represents a VMware admin cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmwareAdminCluster

Returns a new instance of VmwareAdminCluster.



4145
4146
4147
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addon_nodeGoogle::Apis::GkeonpremV1::VmwareAdminAddonNodeConfig

VmwareAdminAddonNodeConfig contains add-on node configurations for VMware admin cluster. Corresponds to the JSON property addonNode



3967
3968
3969
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3967

def addon_node
  @addon_node
end

#annotationsHash<String,String>

Annotations on the VMware admin cluster. This field has the same restrictions as Kubernetes annotations. The total size of all keys and values combined is limited to 256k. Key can have 2 segments: prefix (optional) and name (required) , separated by a slash (/). Prefix must be a DNS subdomain. Name must be 63 characters or less, begin and end with alphanumerics, with dashes (-), underscores (_), dots (.), and alphanumerics between. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


3977
3978
3979
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3977

def annotations
  @annotations
end

#anti_affinity_groupsGoogle::Apis::GkeonpremV1::VmwareAagConfig

Specifies anti affinity group config for the VMware user cluster. Corresponds to the JSON property antiAffinityGroups



3982
3983
3984
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3982

def anti_affinity_groups
  @anti_affinity_groups
end

#authorizationGoogle::Apis::GkeonpremV1::VmwareAdminAuthorizationConfig

VmwareAdminAuthorizationConfig represents configuration for admin cluster authorization. Corresponds to the JSON property authorization



3988
3989
3990
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3988

def authorization
  @authorization
end

#auto_repair_configGoogle::Apis::GkeonpremV1::VmwareAutoRepairConfig

Specifies config to enable/disable auto repair. The cluster-health-controller is deployed only if Enabled is true. Corresponds to the JSON property autoRepairConfig



3994
3995
3996
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3994

def auto_repair_config
  @auto_repair_config
end

#bootstrap_cluster_membershipString

The bootstrap cluster this VMware admin cluster belongs to. Corresponds to the JSON property bootstrapClusterMembership

Returns:

  • (String)


3999
4000
4001
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 3999

def bootstrap_cluster_membership
  @bootstrap_cluster_membership
end

#control_plane_nodeGoogle::Apis::GkeonpremV1::VmwareAdminControlPlaneNodeConfig

VmwareAdminControlPlaneNodeConfig contains control plane node configuration for VMware admin cluster. Corresponds to the JSON property controlPlaneNode



4005
4006
4007
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4005

def control_plane_node
  @control_plane_node
end

#create_timeString

Output only. The time at which VMware admin cluster was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4010
4011
4012
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4010

def create_time
  @create_time
end

#descriptionString

A human readable description of this VMware admin cluster. Corresponds to the JSON property description

Returns:

  • (String)


4015
4016
4017
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4015

def description
  @description
end

#enable_advanced_clusterBoolean Also known as: enable_advanced_cluster?

Enable advanced cluster. Corresponds to the JSON property enableAdvancedCluster

Returns:

  • (Boolean)


4020
4021
4022
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4020

def enable_advanced_cluster
  @enable_advanced_cluster
end

#endpointString

Output only. The DNS name of VMware admin cluster's API server. Corresponds to the JSON property endpoint

Returns:

  • (String)


4026
4027
4028
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4026

def endpoint
  @endpoint
end

#etagString

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding. Allows clients to perform consistent read- modify-writes through optimistic concurrency control. Corresponds to the JSON property etag

Returns:

  • (String)


4034
4035
4036
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4034

def etag
  @etag
end

#fleetGoogle::Apis::GkeonpremV1::Fleet

Fleet related configuration. Fleets are a Google Cloud concept for logically organizing clusters, letting you use and manage multi-cluster capabilities and apply consistent policies across your systems. See Anthos Fleets for more details on Anthos multi-cluster capabilities using Fleets. ## Corresponds to the JSON property fleet



4043
4044
4045
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4043

def fleet
  @fleet
end

#image_typeString

The OS image type for the VMware admin cluster. Corresponds to the JSON property imageType

Returns:

  • (String)


4048
4049
4050
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4048

def image_type
  @image_type
end

#load_balancerGoogle::Apis::GkeonpremV1::VmwareAdminLoadBalancerConfig

VmwareAdminLoadBalancerConfig contains load balancer configuration for VMware admin cluster. Corresponds to the JSON property loadBalancer



4054
4055
4056
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4054

def load_balancer
  @load_balancer
end

#local_nameString

Output only. The object name of the VMware OnPremAdminCluster custom resource. This field is used to support conflicting names when enrolling existing clusters to the API. When used as a part of cluster enrollment, this field will differ from the ID in the resource name. For new clusters, this field will match the user provided cluster name and be visible in the last component of the resource name. It is not modifiable. All users should use this name to access their cluster using gkectl or kubectl and should expect to see the local name when viewing admin cluster controller logs. Corresponds to the JSON property localName

Returns:

  • (String)


4066
4067
4068
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4066

def local_name
  @local_name
end

#nameString

Immutable. The VMware admin cluster resource name. Corresponds to the JSON property name

Returns:

  • (String)


4071
4072
4073
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4071

def name
  @name
end

#network_configGoogle::Apis::GkeonpremV1::VmwareAdminNetworkConfig

VmwareAdminNetworkConfig contains network configuration for VMware admin cluster. Corresponds to the JSON property networkConfig



4077
4078
4079
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4077

def network_config
  @network_config
end

#on_prem_versionString

The Anthos clusters on the VMware version for the admin cluster. Corresponds to the JSON property onPremVersion

Returns:

  • (String)


4082
4083
4084
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4082

def on_prem_version
  @on_prem_version
end

#platform_configGoogle::Apis::GkeonpremV1::VmwarePlatformConfig

VmwarePlatformConfig represents configuration for the VMware platform. Corresponds to the JSON property platformConfig



4087
4088
4089
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4087

def platform_config
  @platform_config
end

#prepared_secretsGoogle::Apis::GkeonpremV1::VmwareAdminPreparedSecretsConfig

VmwareAdminPreparedSecretsConfig represents configuration for admin cluster prepared secrets. Corresponds to the JSON property preparedSecrets



4093
4094
4095
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4093

def prepared_secrets
  @prepared_secrets
end

#private_registry_configGoogle::Apis::GkeonpremV1::VmwareAdminPrivateRegistryConfig

VmwareAdminPrivateRegistryConfig represents configuration for admin cluster registry. Corresponds to the JSON property privateRegistryConfig



4099
4100
4101
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4099

def private_registry_config
  @private_registry_config
end

#proxyGoogle::Apis::GkeonpremV1::VmwareAdminProxy

VmwareAdminProxy represents configuration for admin cluster proxy. Corresponds to the JSON property proxy



4104
4105
4106
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4104

def proxy
  @proxy
end

#reconcilingBoolean Also known as: reconciling?

Output only. If set, there are currently changes in flight to the VMware admin cluster. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


4110
4111
4112
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4110

def reconciling
  @reconciling
end

#stateString

Output only. The current state of VMware admin cluster. Corresponds to the JSON property state

Returns:

  • (String)


4116
4117
4118
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4116

def state
  @state
end

#statusGoogle::Apis::GkeonpremV1::ResourceStatus

ResourceStatus describes why a cluster or node pool has a certain status. (e.g. , ERROR or DEGRADED). Corresponds to the JSON property status



4122
4123
4124
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4122

def status
  @status
end

#uidString

Output only. The unique identifier of the VMware admin cluster. Corresponds to the JSON property uid

Returns:

  • (String)


4127
4128
4129
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4127

def uid
  @uid
end

#update_timeString

Output only. The time at which VMware admin cluster was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4132
4133
4134
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4132

def update_time
  @update_time
end

#validation_checkGoogle::Apis::GkeonpremV1::ValidationCheck

ValidationCheck represents the result of preflight check. Corresponds to the JSON property validationCheck



4137
4138
4139
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4137

def validation_check
  @validation_check
end

#vcenterGoogle::Apis::GkeonpremV1::VmwareAdminVCenterConfig

VmwareAdminVCenterConfig contains VCenter configuration for VMware admin cluster. Corresponds to the JSON property vcenter



4143
4144
4145
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4143

def vcenter
  @vcenter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4150
4151
4152
4153
4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
4166
4167
4168
4169
4170
4171
4172
4173
4174
4175
4176
4177
4178
4179
4180
4181
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4150

def update!(**args)
  @addon_node = args[:addon_node] if args.key?(:addon_node)
  @annotations = args[:annotations] if args.key?(:annotations)
  @anti_affinity_groups = args[:anti_affinity_groups] if args.key?(:anti_affinity_groups)
  @authorization = args[:authorization] if args.key?(:authorization)
  @auto_repair_config = args[:auto_repair_config] if args.key?(:auto_repair_config)
  @bootstrap_cluster_membership = args[:bootstrap_cluster_membership] if args.key?(:bootstrap_cluster_membership)
  @control_plane_node = args[:control_plane_node] if args.key?(:control_plane_node)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @enable_advanced_cluster = args[:enable_advanced_cluster] if args.key?(:enable_advanced_cluster)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @etag = args[:etag] if args.key?(:etag)
  @fleet = args[:fleet] if args.key?(:fleet)
  @image_type = args[:image_type] if args.key?(:image_type)
  @load_balancer = args[:load_balancer] if args.key?(:load_balancer)
  @local_name = args[:local_name] if args.key?(:local_name)
  @name = args[:name] if args.key?(:name)
  @network_config = args[:network_config] if args.key?(:network_config)
  @on_prem_version = args[:on_prem_version] if args.key?(:on_prem_version)
  @platform_config = args[:platform_config] if args.key?(:platform_config)
  @prepared_secrets = args[:prepared_secrets] if args.key?(:prepared_secrets)
  @private_registry_config = args[:private_registry_config] if args.key?(:private_registry_config)
  @proxy = args[:proxy] if args.key?(:proxy)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @validation_check = args[:validation_check] if args.key?(:validation_check)
  @vcenter = args[:vcenter] if args.key?(:vcenter)
end