Class: Google::Apis::GkeonpremV1::VmwareAdminF5BigIpConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb

Overview

VmwareAdminF5BigIpConfig represents configuration parameters for an F5 BIG-IP load balancer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmwareAdminF5BigIpConfig

Returns a new instance of VmwareAdminF5BigIpConfig.



4239
4240
4241
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

The load balancer's IP address. Corresponds to the JSON property address

Returns:

  • (String)


4226
4227
4228
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4226

def address
  @address
end

#partitionString

The preexisting partition to be used by the load balancer. This partition is usually created for the admin cluster for example: 'my-f5-admin-partition'. Corresponds to the JSON property partition

Returns:

  • (String)


4232
4233
4234
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4232

def partition
  @partition
end

#snat_poolString

The pool name. Only necessary, if using SNAT. Corresponds to the JSON property snatPool

Returns:

  • (String)


4237
4238
4239
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4237

def snat_pool
  @snat_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4244
4245
4246
4247
4248
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4244

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @partition = args[:partition] if args.key?(:partition)
  @snat_pool = args[:snat_pool] if args.key?(:snat_pool)
end