Class: Google::Apis::GkeonpremV1::VmwareAdminPrivateRegistryConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkeonpremV1::VmwareAdminPrivateRegistryConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb
Overview
VmwareAdminPrivateRegistryConfig represents configuration for admin cluster registry.
Instance Attribute Summary collapse
-
#address ⇒ String
The registry address.
-
#ca_cert ⇒ String
When the container runtime pulls an image from private registry, the registry must prove its identity by presenting a certificate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmwareAdminPrivateRegistryConfig
constructor
A new instance of VmwareAdminPrivateRegistryConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmwareAdminPrivateRegistryConfig
Returns a new instance of VmwareAdminPrivateRegistryConfig.
4501 4502 4503 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4501 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
The registry address.
Corresponds to the JSON property address
4491 4492 4493 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4491 def address @address end |
#ca_cert ⇒ String
When the container runtime pulls an image from private registry, the registry
must prove its identity by presenting a certificate. The registry's
certificate is signed by a certificate authority (CA). The container runtime
uses the CA's certificate to validate the registry's certificate.
Corresponds to the JSON property caCert
4499 4500 4501 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4499 def ca_cert @ca_cert end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4506 4507 4508 4509 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4506 def update!(**args) @address = args[:address] if args.key?(:address) @ca_cert = args[:ca_cert] if args.key?(:ca_cert) end |