Class: Google::Apis::GkeonpremV1::VmwareAdminVipConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkeonpremV1::VmwareAdminVipConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb
Overview
VmwareAdminVipConfig for VMware load balancer configurations.
Instance Attribute Summary collapse
-
#addons_vip ⇒ String
The VIP to configure the load balancer for add-ons.
-
#control_plane_vip ⇒ String
The VIP which you previously set aside for the Kubernetes API of the admin cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmwareAdminVipConfig
constructor
A new instance of VmwareAdminVipConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmwareAdminVipConfig
Returns a new instance of VmwareAdminVipConfig.
4690 4691 4692 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4690 def initialize(**args) update!(**args) end |
Instance Attribute Details
#addons_vip ⇒ String
The VIP to configure the load balancer for add-ons.
Corresponds to the JSON property addonsVip
4682 4683 4684 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4682 def addons_vip @addons_vip end |
#control_plane_vip ⇒ String
The VIP which you previously set aside for the Kubernetes API of the admin
cluster.
Corresponds to the JSON property controlPlaneVip
4688 4689 4690 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4688 def control_plane_vip @control_plane_vip end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4695 4696 4697 4698 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4695 def update!(**args) @addons_vip = args[:addons_vip] if args.key?(:addons_vip) @control_plane_vip = args[:control_plane_vip] if args.key?(:control_plane_vip) end |