Class: Google::Apis::GkeonpremV1::VmwareCluster
- Inherits:
-
Object
- Object
- Google::Apis::GkeonpremV1::VmwareCluster
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb
Overview
Resource that represents a VMware user cluster. ##
Instance Attribute Summary collapse
-
#admin_cluster_membership ⇒ String
Required.
-
#admin_cluster_name ⇒ String
Output only.
-
#annotations ⇒ Hash<String,String>
Annotations on the VMware user cluster.
-
#anti_affinity_groups ⇒ Google::Apis::GkeonpremV1::VmwareAagConfig
Specifies anti affinity group config for the VMware user cluster.
-
#authorization ⇒ Google::Apis::GkeonpremV1::Authorization
Authorization defines the On-Prem cluster authorization configuration to bootstrap onto the admin cluster.
-
#auto_repair_config ⇒ Google::Apis::GkeonpremV1::VmwareAutoRepairConfig
Specifies config to enable/disable auto repair.
-
#binary_authorization ⇒ Google::Apis::GkeonpremV1::BinaryAuthorization
Configuration for Binary Authorization.
-
#control_plane_node ⇒ Google::Apis::GkeonpremV1::VmwareControlPlaneNodeConfig
Specifies control plane node config for the VMware user cluster.
-
#create_time ⇒ String
Output only.
-
#dataplane_v2 ⇒ Google::Apis::GkeonpremV1::VmwareDataplaneV2Config
Contains configurations for Dataplane V2, which is optimized dataplane for Kubernetes networking.
-
#delete_time ⇒ String
Output only.
-
#description ⇒ String
A human readable description of this VMware user cluster.
-
#disable_bundled_ingress ⇒ Boolean
(also: #disable_bundled_ingress?)
Disable bundled ingress.
-
#enable_advanced_cluster ⇒ Boolean
(also: #enable_advanced_cluster?)
Enable advanced cluster.
-
#enable_control_plane_v2 ⇒ Boolean
(also: #enable_control_plane_v2?)
Enable control plane V2.
-
#endpoint ⇒ String
Output only.
-
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding.
-
#fleet ⇒ Google::Apis::GkeonpremV1::Fleet
Fleet related configuration.
-
#load_balancer ⇒ Google::Apis::GkeonpremV1::VmwareLoadBalancerConfig
Specifies the locad balancer config for the VMware user cluster.
-
#local_name ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#network_config ⇒ Google::Apis::GkeonpremV1::VmwareNetworkConfig
Specifies network config for the VMware user cluster.
-
#on_prem_version ⇒ String
Required.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::GkeonpremV1::ResourceStatus
ResourceStatus describes why a cluster or node pool has a certain status.
-
#storage ⇒ Google::Apis::GkeonpremV1::VmwareStorageConfig
Specifies vSphere CSI components deployment config in the VMware user cluster.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#upgrade_policy ⇒ Google::Apis::GkeonpremV1::VmwareClusterUpgradePolicy
VmwareClusterUpgradePolicy defines the cluster upgrade policy.
-
#validation_check ⇒ Google::Apis::GkeonpremV1::ValidationCheck
ValidationCheck represents the result of preflight check.
-
#vcenter ⇒ Google::Apis::GkeonpremV1::VmwareVCenterConfig
Represents configuration for the VMware VCenter for the user cluster.
-
#vm_tracking_enabled ⇒ Boolean
(also: #vm_tracking_enabled?)
Enable VM tracking.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmwareCluster
constructor
A new instance of VmwareCluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmwareCluster
Returns a new instance of VmwareCluster.
4971 4972 4973 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4971 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_cluster_membership ⇒ String
Required. The admin cluster this VMware user cluster belongs to. This is the
full resource name of the admin cluster's fleet membership. In the future,
references to other resource types might be allowed if admin clusters are
modeled as their own resources.
Corresponds to the JSON property adminClusterMembership
4778 4779 4780 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4778 def admin_cluster_membership @admin_cluster_membership end |
#admin_cluster_name ⇒ String
Output only. The resource name of the VMware admin cluster hosting this user
cluster.
Corresponds to the JSON property adminClusterName
4784 4785 4786 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4784 def admin_cluster_name @admin_cluster_name end |
#annotations ⇒ Hash<String,String>
Annotations on the VMware user cluster. This field has the same restrictions
as Kubernetes annotations. The total size of all keys and values combined is
limited to 256k. Key can have 2 segments: prefix (optional) and name (required)
, separated by a slash (/). Prefix must be a DNS subdomain. Name must be 63
characters or less, begin and end with alphanumerics, with dashes (-),
underscores (_), dots (.), and alphanumerics between.
Corresponds to the JSON property annotations
4794 4795 4796 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4794 def annotations @annotations end |
#anti_affinity_groups ⇒ Google::Apis::GkeonpremV1::VmwareAagConfig
Specifies anti affinity group config for the VMware user cluster.
Corresponds to the JSON property antiAffinityGroups
4799 4800 4801 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4799 def anti_affinity_groups @anti_affinity_groups end |
#authorization ⇒ Google::Apis::GkeonpremV1::Authorization
Authorization defines the On-Prem cluster authorization configuration to
bootstrap onto the admin cluster.
Corresponds to the JSON property authorization
4805 4806 4807 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4805 def @authorization end |
#auto_repair_config ⇒ Google::Apis::GkeonpremV1::VmwareAutoRepairConfig
Specifies config to enable/disable auto repair. The cluster-health-controller
is deployed only if Enabled is true.
Corresponds to the JSON property autoRepairConfig
4811 4812 4813 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4811 def auto_repair_config @auto_repair_config end |
#binary_authorization ⇒ Google::Apis::GkeonpremV1::BinaryAuthorization
Configuration for Binary Authorization.
Corresponds to the JSON property binaryAuthorization
4816 4817 4818 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4816 def @binary_authorization end |
#control_plane_node ⇒ Google::Apis::GkeonpremV1::VmwareControlPlaneNodeConfig
Specifies control plane node config for the VMware user cluster.
Corresponds to the JSON property controlPlaneNode
4821 4822 4823 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4821 def control_plane_node @control_plane_node end |
#create_time ⇒ String
Output only. The time at which VMware user cluster was created.
Corresponds to the JSON property createTime
4826 4827 4828 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4826 def create_time @create_time end |
#dataplane_v2 ⇒ Google::Apis::GkeonpremV1::VmwareDataplaneV2Config
Contains configurations for Dataplane V2, which is optimized dataplane for
Kubernetes networking. For more information, see: https://cloud.google.com/
kubernetes-engine/docs/concepts/dataplane-v2
Corresponds to the JSON property dataplaneV2
4833 4834 4835 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4833 def dataplane_v2 @dataplane_v2 end |
#delete_time ⇒ String
Output only. The time at which VMware user cluster was deleted.
Corresponds to the JSON property deleteTime
4838 4839 4840 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4838 def delete_time @delete_time end |
#description ⇒ String
A human readable description of this VMware user cluster.
Corresponds to the JSON property description
4843 4844 4845 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4843 def description @description end |
#disable_bundled_ingress ⇒ Boolean Also known as: disable_bundled_ingress?
Disable bundled ingress.
Corresponds to the JSON property disableBundledIngress
4848 4849 4850 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4848 def disable_bundled_ingress @disable_bundled_ingress end |
#enable_advanced_cluster ⇒ Boolean Also known as: enable_advanced_cluster?
Enable advanced cluster.
Corresponds to the JSON property enableAdvancedCluster
4854 4855 4856 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4854 def enable_advanced_cluster @enable_advanced_cluster end |
#enable_control_plane_v2 ⇒ Boolean Also known as: enable_control_plane_v2?
Enable control plane V2. Default to false.
Corresponds to the JSON property enableControlPlaneV2
4860 4861 4862 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4860 def enable_control_plane_v2 @enable_control_plane_v2 end |
#endpoint ⇒ String
Output only. The DNS name of VMware user cluster's API server.
Corresponds to the JSON property endpoint
4866 4867 4868 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4866 def endpoint @endpoint end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and may be sent on update and delete requests to ensure the client has an up-
to-date value before proceeding. Allows clients to perform consistent read-
modify-writes through optimistic concurrency control.
Corresponds to the JSON property etag
4874 4875 4876 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4874 def etag @etag end |
#fleet ⇒ Google::Apis::GkeonpremV1::Fleet
Fleet related configuration. Fleets are a Google Cloud concept for logically
organizing clusters, letting you use and manage multi-cluster capabilities and
apply consistent policies across your systems. See Anthos Fleets for more details on
Anthos multi-cluster capabilities using Fleets. ##
Corresponds to the JSON property fleet
4883 4884 4885 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4883 def fleet @fleet end |
#load_balancer ⇒ Google::Apis::GkeonpremV1::VmwareLoadBalancerConfig
Specifies the locad balancer config for the VMware user cluster.
Corresponds to the JSON property loadBalancer
4888 4889 4890 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4888 def load_balancer @load_balancer end |
#local_name ⇒ String
Output only. The object name of the VMware OnPremUserCluster custom resource
on the associated admin cluster. This field is used to support conflicting
names when enrolling existing clusters to the API. When used as a part of
cluster enrollment, this field will differ from the ID in the resource name.
For new clusters, this field will match the user provided cluster name and be
visible in the last component of the resource name. It is not modifiable. All
users should use this name to access their cluster using gkectl or kubectl and
should expect to see the local name when viewing admin cluster controller logs.
Corresponds to the JSON property localName
4900 4901 4902 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4900 def local_name @local_name end |
#name ⇒ String
Immutable. The VMware user cluster resource name.
Corresponds to the JSON property name
4905 4906 4907 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4905 def name @name end |
#network_config ⇒ Google::Apis::GkeonpremV1::VmwareNetworkConfig
Specifies network config for the VMware user cluster.
Corresponds to the JSON property networkConfig
4910 4911 4912 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4910 def network_config @network_config end |
#on_prem_version ⇒ String
Required. The Anthos clusters on the VMware version for your user cluster.
Corresponds to the JSON property onPremVersion
4915 4916 4917 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4915 def on_prem_version @on_prem_version end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. If set, there are currently changes in flight to the VMware user
cluster.
Corresponds to the JSON property reconciling
4921 4922 4923 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4921 def reconciling @reconciling end |
#state ⇒ String
Output only. The current state of VMware user cluster.
Corresponds to the JSON property state
4927 4928 4929 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4927 def state @state end |
#status ⇒ Google::Apis::GkeonpremV1::ResourceStatus
ResourceStatus describes why a cluster or node pool has a certain status. (e.g.
, ERROR or DEGRADED).
Corresponds to the JSON property status
4933 4934 4935 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4933 def status @status end |
#storage ⇒ Google::Apis::GkeonpremV1::VmwareStorageConfig
Specifies vSphere CSI components deployment config in the VMware user cluster.
Corresponds to the JSON property storage
4938 4939 4940 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4938 def storage @storage end |
#uid ⇒ String
Output only. The unique identifier of the VMware user cluster.
Corresponds to the JSON property uid
4943 4944 4945 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4943 def uid @uid end |
#update_time ⇒ String
Output only. The time at which VMware user cluster was last updated.
Corresponds to the JSON property updateTime
4948 4949 4950 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4948 def update_time @update_time end |
#upgrade_policy ⇒ Google::Apis::GkeonpremV1::VmwareClusterUpgradePolicy
VmwareClusterUpgradePolicy defines the cluster upgrade policy.
Corresponds to the JSON property upgradePolicy
4953 4954 4955 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4953 def upgrade_policy @upgrade_policy end |
#validation_check ⇒ Google::Apis::GkeonpremV1::ValidationCheck
ValidationCheck represents the result of preflight check.
Corresponds to the JSON property validationCheck
4958 4959 4960 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4958 def validation_check @validation_check end |
#vcenter ⇒ Google::Apis::GkeonpremV1::VmwareVCenterConfig
Represents configuration for the VMware VCenter for the user cluster.
Corresponds to the JSON property vcenter
4963 4964 4965 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4963 def vcenter @vcenter end |
#vm_tracking_enabled ⇒ Boolean Also known as: vm_tracking_enabled?
Enable VM tracking.
Corresponds to the JSON property vmTrackingEnabled
4968 4969 4970 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4968 def vm_tracking_enabled @vm_tracking_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4976 def update!(**args) @admin_cluster_membership = args[:admin_cluster_membership] if args.key?(:admin_cluster_membership) @admin_cluster_name = args[:admin_cluster_name] if args.key?(:admin_cluster_name) @annotations = args[:annotations] if args.key?(:annotations) @anti_affinity_groups = args[:anti_affinity_groups] if args.key?(:anti_affinity_groups) @authorization = args[:authorization] if args.key?(:authorization) @auto_repair_config = args[:auto_repair_config] if args.key?(:auto_repair_config) @binary_authorization = args[:binary_authorization] if args.key?(:binary_authorization) @control_plane_node = args[:control_plane_node] if args.key?(:control_plane_node) @create_time = args[:create_time] if args.key?(:create_time) @dataplane_v2 = args[:dataplane_v2] if args.key?(:dataplane_v2) @delete_time = args[:delete_time] if args.key?(:delete_time) @description = args[:description] if args.key?(:description) @disable_bundled_ingress = args[:disable_bundled_ingress] if args.key?(:disable_bundled_ingress) @enable_advanced_cluster = args[:enable_advanced_cluster] if args.key?(:enable_advanced_cluster) @enable_control_plane_v2 = args[:enable_control_plane_v2] if args.key?(:enable_control_plane_v2) @endpoint = args[:endpoint] if args.key?(:endpoint) @etag = args[:etag] if args.key?(:etag) @fleet = args[:fleet] if args.key?(:fleet) @load_balancer = args[:load_balancer] if args.key?(:load_balancer) @local_name = args[:local_name] if args.key?(:local_name) @name = args[:name] if args.key?(:name) @network_config = args[:network_config] if args.key?(:network_config) @on_prem_version = args[:on_prem_version] if args.key?(:on_prem_version) @reconciling = args[:reconciling] if args.key?(:reconciling) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @storage = args[:storage] if args.key?(:storage) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @upgrade_policy = args[:upgrade_policy] if args.key?(:upgrade_policy) @validation_check = args[:validation_check] if args.key?(:validation_check) @vcenter = args[:vcenter] if args.key?(:vcenter) @vm_tracking_enabled = args[:vm_tracking_enabled] if args.key?(:vm_tracking_enabled) end |