Class: Google::Apis::GkeonpremV1::VmwareF5BigIpConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkeonpremV1::VmwareF5BigIpConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb
Overview
Represents configuration parameters for an F5 BIG-IP load balancer.
Instance Attribute Summary collapse
-
#address ⇒ String
The load balancer's IP address.
-
#partition ⇒ String
The preexisting partition to be used by the load balancer.
-
#snat_pool ⇒ String
The pool name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmwareF5BigIpConfig
constructor
A new instance of VmwareF5BigIpConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmwareF5BigIpConfig
Returns a new instance of VmwareF5BigIpConfig.
5207 5208 5209 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5207 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
The load balancer's IP address.
Corresponds to the JSON property address
5194 5195 5196 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5194 def address @address end |
#partition ⇒ String
The preexisting partition to be used by the load balancer. This partition is
usually created for the admin cluster for example: 'my-f5-admin-partition'.
Corresponds to the JSON property partition
5200 5201 5202 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5200 def partition @partition end |
#snat_pool ⇒ String
The pool name. Only necessary, if using SNAT.
Corresponds to the JSON property snatPool
5205 5206 5207 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5205 def snat_pool @snat_pool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5212 5213 5214 5215 5216 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5212 def update!(**args) @address = args[:address] if args.key?(:address) @partition = args[:partition] if args.key?(:partition) @snat_pool = args[:snat_pool] if args.key?(:snat_pool) end |