Class: Google::Apis::GkeonpremV1::VmwareNodePool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb

Overview

Resource VmwareNodePool represents a VMware node pool. ##

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmwareNodePool

Returns a new instance of VmwareNodePool.



5670
5671
5672
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5670

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Annotations on the node pool. This field has the same restrictions as Kubernetes annotations. The total size of all keys and values combined is limited to 256k. Key can have 2 segments: prefix (optional) and name (required) , separated by a slash (/). Prefix must be a DNS subdomain. Name must be 63 characters or less, begin and end with alphanumerics, with dashes (-), underscores (_), dots (.), and alphanumerics between. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


5595
5596
5597
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5595

def annotations
  @annotations
end

#configGoogle::Apis::GkeonpremV1::VmwareNodeConfig

Parameters that describe the configuration of all nodes within a given node pool. Corresponds to the JSON property config



5601
5602
5603
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5601

def config
  @config
end

#create_timeString

Output only. The time at which this node pool was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5606
5607
5608
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5606

def create_time
  @create_time
end

#delete_timeString

Output only. The time at which this node pool was deleted. If the resource is not deleted, this must be empty Corresponds to the JSON property deleteTime

Returns:

  • (String)


5612
5613
5614
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5612

def delete_time
  @delete_time
end

#display_nameString

The display name for the node pool. Corresponds to the JSON property displayName

Returns:

  • (String)


5617
5618
5619
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5617

def display_name
  @display_name
end

#etagString

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding. Allows clients to perform consistent read- modify-writes through optimistic concurrency control. Corresponds to the JSON property etag

Returns:

  • (String)


5625
5626
5627
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5625

def etag
  @etag
end

#nameString

Immutable. The resource name of this node pool. Corresponds to the JSON property name

Returns:

  • (String)


5630
5631
5632
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5630

def name
  @name
end

#node_pool_autoscalingGoogle::Apis::GkeonpremV1::VmwareNodePoolAutoscalingConfig

NodePoolAutoscaling config for the NodePool to allow for the kubernetes to scale NodePool. Corresponds to the JSON property nodePoolAutoscaling



5636
5637
5638
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5636

def node_pool_autoscaling
  @node_pool_autoscaling
end

#on_prem_versionString

Anthos version for the node pool. Defaults to the user cluster version. Corresponds to the JSON property onPremVersion

Returns:

  • (String)


5641
5642
5643
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5641

def on_prem_version
  @on_prem_version
end

#reconcilingBoolean Also known as: reconciling?

Output only. If set, there are currently changes in flight to the node pool. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


5646
5647
5648
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5646

def reconciling
  @reconciling
end

#stateString

Output only. The current state of the node pool. Corresponds to the JSON property state

Returns:

  • (String)


5652
5653
5654
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5652

def state
  @state
end

#statusGoogle::Apis::GkeonpremV1::ResourceStatus

ResourceStatus describes why a cluster or node pool has a certain status. (e.g. , ERROR or DEGRADED). Corresponds to the JSON property status



5658
5659
5660
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5658

def status
  @status
end

#uidString

Output only. The unique identifier of the node pool. Corresponds to the JSON property uid

Returns:

  • (String)


5663
5664
5665
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5663

def uid
  @uid
end

#update_timeString

Output only. The time at which this node pool was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5668
5669
5670
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5668

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
5688
5689
5690
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5675

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @config = args[:config] if args.key?(:config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @node_pool_autoscaling = args[:node_pool_autoscaling] if args.key?(:node_pool_autoscaling)
  @on_prem_version = args[:on_prem_version] if args.key?(:on_prem_version)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end