Class: Google::Apis::GkeonpremV1::ListVmwareClustersResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkeonpremV1::ListVmwareClustersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb
Overview
Response message for listing VMware Clusters.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
-
#vmware_clusters ⇒ Array<Google::Apis::GkeonpremV1::VmwareCluster>
The list of VMware Cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListVmwareClustersResponse
constructor
A new instance of ListVmwareClustersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListVmwareClustersResponse
Returns a new instance of ListVmwareClustersResponse.
2955 2956 2957 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 2955 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return. If the token
is not empty this means that more results are available and should be
retrieved by repeating the request with the provided page token.
Corresponds to the JSON property nextPageToken
2943 2944 2945 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 2943 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2948 2949 2950 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 2948 def unreachable @unreachable end |
#vmware_clusters ⇒ Array<Google::Apis::GkeonpremV1::VmwareCluster>
The list of VMware Cluster.
Corresponds to the JSON property vmwareClusters
2953 2954 2955 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 2953 def vmware_clusters @vmware_clusters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2960 2961 2962 2963 2964 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 2960 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) @vmware_clusters = args[:vmware_clusters] if args.key?(:vmware_clusters) end |