Class: Google::Apis::GkeonpremV1::VmwareAdminLoadBalancerConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkeonpremV1::VmwareAdminLoadBalancerConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb
Overview
VmwareAdminLoadBalancerConfig contains load balancer configuration for VMware admin cluster.
Instance Attribute Summary collapse
-
#f5_config ⇒ Google::Apis::GkeonpremV1::VmwareAdminF5BigIpConfig
VmwareAdminF5BigIpConfig represents configuration parameters for an F5 BIG-IP load balancer.
-
#manual_lb_config ⇒ Google::Apis::GkeonpremV1::VmwareAdminManualLbConfig
Manually configured load balancers.
-
#metal_lb_config ⇒ Google::Apis::GkeonpremV1::VmwareAdminMetalLbConfig
VmwareAdminMetalLbConfig represents configuration parameters for a MetalLB load balancer.
-
#seesaw_config ⇒ Google::Apis::GkeonpremV1::VmwareAdminSeesawConfig
VmwareSeesawConfig represents configuration parameters for an already existing Seesaw load balancer.
-
#vip_config ⇒ Google::Apis::GkeonpremV1::VmwareAdminVipConfig
VmwareAdminVipConfig for VMware load balancer configurations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmwareAdminLoadBalancerConfig
constructor
A new instance of VmwareAdminLoadBalancerConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmwareAdminLoadBalancerConfig
Returns a new instance of VmwareAdminLoadBalancerConfig.
4317 4318 4319 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#f5_config ⇒ Google::Apis::GkeonpremV1::VmwareAdminF5BigIpConfig
VmwareAdminF5BigIpConfig represents configuration parameters for an F5 BIG-IP
load balancer.
Corresponds to the JSON property f5Config
4279 4280 4281 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4279 def f5_config @f5_config end |
#manual_lb_config ⇒ Google::Apis::GkeonpremV1::VmwareAdminManualLbConfig
Manually configured load balancers.
Corresponds to the JSON property manualLbConfig
4284 4285 4286 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4284 def manual_lb_config @manual_lb_config end |
#metal_lb_config ⇒ Google::Apis::GkeonpremV1::VmwareAdminMetalLbConfig
VmwareAdminMetalLbConfig represents configuration parameters for a MetalLB
load balancer. For admin clusters, currently no configurations is needed.
Corresponds to the JSON property metalLbConfig
4290 4291 4292 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4290 def @metal_lb_config end |
#seesaw_config ⇒ Google::Apis::GkeonpremV1::VmwareAdminSeesawConfig
VmwareSeesawConfig represents configuration parameters for an already existing
Seesaw load balancer. IMPORTANT: Please note that the Anthos On-Prem API will
not generate or update Seesaw configurations it can only bind a pre-existing
configuration to a new user cluster. IMPORTANT: When attempting to create a
user cluster with a pre-existing Seesaw load balancer you will need to follow
some preparation steps before calling the 'CreateVmwareCluster' API method.
First you will need to create the user cluster's namespace via kubectl. The
namespace will need to use the following naming convention : -gke-onprem-mgmt
or -gke-onprem-mgmt depending on whether you used the 'VmwareCluster.
local_name' to disambiguate collisions; for more context see the documentation
of 'VmwareCluster.local_name'. Once the namespace is created you will need to
create a secret resource via kubectl. This secret will contain copies of your
Seesaw credentials. The Secret must be called 'user-cluster-creds' and contain
Seesaw's SSH and Cert credentials. The credentials must be keyed with the
following names: 'seesaw-ssh-private-key', 'seesaw-ssh-public-key', 'seesaw-
ssh-ca-key', 'seesaw-ssh-ca-cert'.
Corresponds to the JSON property seesawConfig
4310 4311 4312 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4310 def seesaw_config @seesaw_config end |
#vip_config ⇒ Google::Apis::GkeonpremV1::VmwareAdminVipConfig
VmwareAdminVipConfig for VMware load balancer configurations.
Corresponds to the JSON property vipConfig
4315 4316 4317 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4315 def vip_config @vip_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4322 4323 4324 4325 4326 4327 4328 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4322 def update!(**args) @f5_config = args[:f5_config] if args.key?(:f5_config) @manual_lb_config = args[:manual_lb_config] if args.key?(:manual_lb_config) @metal_lb_config = args[:metal_lb_config] if args.key?(:metal_lb_config) @seesaw_config = args[:seesaw_config] if args.key?(:seesaw_config) @vip_config = args[:vip_config] if args.key?(:vip_config) end |