Class: Google::Apis::GkeonpremV1::VmwareAdminManualLbConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkeonpremV1::VmwareAdminManualLbConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb
Instance Attribute Summary collapse
-
#addons_node_port ⇒ Fixnum
NodePort for add-ons server in the admin cluster.
-
#control_plane_node_port ⇒ Fixnum
NodePort for control plane service.
-
#ingress_http_node_port ⇒ Fixnum
NodePort for ingress service's http.
-
#ingress_https_node_port ⇒ Fixnum
NodePort for ingress service's https.
-
#konnectivity_server_node_port ⇒ Fixnum
NodePort for konnectivity server service running as a sidecar in each kube- apiserver pod (ex. 30564).
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmwareAdminManualLbConfig
constructor
A new instance of VmwareAdminManualLbConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmwareAdminManualLbConfig
Returns a new instance of VmwareAdminManualLbConfig.
4364 4365 4366 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#addons_node_port ⇒ Fixnum
NodePort for add-ons server in the admin cluster.
Corresponds to the JSON property addonsNodePort
4338 4339 4340 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4338 def addons_node_port @addons_node_port end |
#control_plane_node_port ⇒ Fixnum
NodePort for control plane service. The Kubernetes API server in the admin
cluster is implemented as a Service of type NodePort (ex. 30968).
Corresponds to the JSON property controlPlaneNodePort
4344 4345 4346 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4344 def control_plane_node_port @control_plane_node_port end |
#ingress_http_node_port ⇒ Fixnum
NodePort for ingress service's http. The ingress service in the admin cluster
is implemented as a Service of type NodePort (ex. 32527).
Corresponds to the JSON property ingressHttpNodePort
4350 4351 4352 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4350 def ingress_http_node_port @ingress_http_node_port end |
#ingress_https_node_port ⇒ Fixnum
NodePort for ingress service's https. The ingress service in the admin cluster
is implemented as a Service of type NodePort (ex. 30139).
Corresponds to the JSON property ingressHttpsNodePort
4356 4357 4358 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4356 def ingress_https_node_port @ingress_https_node_port end |
#konnectivity_server_node_port ⇒ Fixnum
NodePort for konnectivity server service running as a sidecar in each kube-
apiserver pod (ex. 30564).
Corresponds to the JSON property konnectivityServerNodePort
4362 4363 4364 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4362 def konnectivity_server_node_port @konnectivity_server_node_port end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4369 4370 4371 4372 4373 4374 4375 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 4369 def update!(**args) @addons_node_port = args[:addons_node_port] if args.key?(:addons_node_port) @control_plane_node_port = args[:control_plane_node_port] if args.key?(:control_plane_node_port) @ingress_http_node_port = args[:ingress_http_node_port] if args.key?(:ingress_http_node_port) @ingress_https_node_port = args[:ingress_https_node_port] if args.key?(:ingress_https_node_port) @konnectivity_server_node_port = args[:konnectivity_server_node_port] if args.key?(:konnectivity_server_node_port) end |