Class: Google::Apis::GkeonpremV1::VmwareManualLbConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkeonpremV1::VmwareManualLbConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb
Overview
Represents configuration parameters for an already existing manual load balancer. Given the nature of manual load balancers it is expected that said load balancer will be fully managed by users. IMPORTANT: Please note that the Anthos On-Prem API will not generate or update ManualLB configurations it can only bind a pre-existing configuration to a new VMware user cluster.
Instance Attribute Summary collapse
-
#control_plane_node_port ⇒ Fixnum
NodePort for control plane service.
-
#ingress_http_node_port ⇒ Fixnum
NodePort for ingress service's http.
-
#ingress_https_node_port ⇒ Fixnum
NodePort for ingress service's https.
-
#konnectivity_server_node_port ⇒ Fixnum
NodePort for konnectivity server service running as a sidecar in each kube- apiserver pod (ex. 30564).
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmwareManualLbConfig
constructor
A new instance of VmwareManualLbConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmwareManualLbConfig
Returns a new instance of VmwareManualLbConfig.
5401 5402 5403 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#control_plane_node_port ⇒ Fixnum
NodePort for control plane service. The Kubernetes API server in the admin
cluster is implemented as a Service of type NodePort (ex. 30968).
Corresponds to the JSON property controlPlaneNodePort
5381 5382 5383 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5381 def control_plane_node_port @control_plane_node_port end |
#ingress_http_node_port ⇒ Fixnum
NodePort for ingress service's http. The ingress service in the admin cluster
is implemented as a Service of type NodePort (ex. 32527).
Corresponds to the JSON property ingressHttpNodePort
5387 5388 5389 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5387 def ingress_http_node_port @ingress_http_node_port end |
#ingress_https_node_port ⇒ Fixnum
NodePort for ingress service's https. The ingress service in the admin cluster
is implemented as a Service of type NodePort (ex. 30139).
Corresponds to the JSON property ingressHttpsNodePort
5393 5394 5395 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5393 def ingress_https_node_port @ingress_https_node_port end |
#konnectivity_server_node_port ⇒ Fixnum
NodePort for konnectivity server service running as a sidecar in each kube-
apiserver pod (ex. 30564).
Corresponds to the JSON property konnectivityServerNodePort
5399 5400 5401 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5399 def konnectivity_server_node_port @konnectivity_server_node_port end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5406 5407 5408 5409 5410 5411 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5406 def update!(**args) @control_plane_node_port = args[:control_plane_node_port] if args.key?(:control_plane_node_port) @ingress_http_node_port = args[:ingress_http_node_port] if args.key?(:ingress_http_node_port) @ingress_https_node_port = args[:ingress_https_node_port] if args.key?(:ingress_https_node_port) @konnectivity_server_node_port = args[:konnectivity_server_node_port] if args.key?(:konnectivity_server_node_port) end |