Class: Google::Apis::GkeonpremV1::VmwareNodeConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkeonpremV1::VmwareNodeConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb
Overview
Parameters that describe the configuration of all nodes within a given node pool.
Instance Attribute Summary collapse
-
#boot_disk_size_gb ⇒ Fixnum
VMware disk size to be used during creation.
-
#cpus ⇒ Fixnum
The number of CPUs for each node in the node pool.
-
#enable_load_balancer ⇒ Boolean
(also: #enable_load_balancer?)
Allow node pool traffic to be load balanced.
-
#image ⇒ String
The OS image name in vCenter, only valid when using Windows.
-
#image_type ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
The map of Kubernetes labels (key/value pairs) to be applied to each node.
-
#memory_mb ⇒ Fixnum
The megabytes of memory for each node in the node pool.
-
#replicas ⇒ Fixnum
The number of nodes in the node pool.
-
#taints ⇒ Array<Google::Apis::GkeonpremV1::NodeTaint>
The initial taints assigned to nodes of this node pool.
-
#vsphere_config ⇒ Google::Apis::GkeonpremV1::VmwareVsphereConfig
VmwareVsphereConfig represents configuration for the VMware VCenter for node pool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmwareNodeConfig
constructor
A new instance of VmwareNodeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmwareNodeConfig
Returns a new instance of VmwareNodeConfig.
5564 5565 5566 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5564 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boot_disk_size_gb ⇒ Fixnum
VMware disk size to be used during creation.
Corresponds to the JSON property bootDiskSizeGb
5506 5507 5508 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5506 def boot_disk_size_gb @boot_disk_size_gb end |
#cpus ⇒ Fixnum
The number of CPUs for each node in the node pool.
Corresponds to the JSON property cpus
5511 5512 5513 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5511 def cpus @cpus end |
#enable_load_balancer ⇒ Boolean Also known as: enable_load_balancer?
Allow node pool traffic to be load balanced. Only works for clusters with
MetalLB load balancers.
Corresponds to the JSON property enableLoadBalancer
5517 5518 5519 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5517 def enable_load_balancer @enable_load_balancer end |
#image ⇒ String
The OS image name in vCenter, only valid when using Windows.
Corresponds to the JSON property image
5523 5524 5525 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5523 def image @image end |
#image_type ⇒ String
Required. The OS image to be used for each node in a node pool. Currently cos
, cos_cgv2, ubuntu, ubuntu_cgv2, ubuntu_containerd and windows are
supported.
Corresponds to the JSON property imageType
5530 5531 5532 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5530 def image_type @image_type end |
#labels ⇒ Hash<String,String>
The map of Kubernetes labels (key/value pairs) to be applied to each node.
These will added in addition to any default label(s) that Kubernetes may apply
to the node. In case of conflict in label keys, the applied set may differ
depending on the Kubernetes version -- it's best to assume the behavior is
undefined and conflicts should be avoided. For more information, including
usage and the valid values, see: https://kubernetes.io/docs/concepts/overview/
working-with-objects/labels/
Corresponds to the JSON property labels
5541 5542 5543 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5541 def labels @labels end |
#memory_mb ⇒ Fixnum
The megabytes of memory for each node in the node pool.
Corresponds to the JSON property memoryMb
5546 5547 5548 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5546 def memory_mb @memory_mb end |
#replicas ⇒ Fixnum
The number of nodes in the node pool.
Corresponds to the JSON property replicas
5551 5552 5553 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5551 def replicas @replicas end |
#taints ⇒ Array<Google::Apis::GkeonpremV1::NodeTaint>
The initial taints assigned to nodes of this node pool.
Corresponds to the JSON property taints
5556 5557 5558 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5556 def taints @taints end |
#vsphere_config ⇒ Google::Apis::GkeonpremV1::VmwareVsphereConfig
VmwareVsphereConfig represents configuration for the VMware VCenter for node
pool.
Corresponds to the JSON property vsphereConfig
5562 5563 5564 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5562 def vsphere_config @vsphere_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5569 5570 5571 5572 5573 5574 5575 5576 5577 5578 5579 5580 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5569 def update!(**args) @boot_disk_size_gb = args[:boot_disk_size_gb] if args.key?(:boot_disk_size_gb) @cpus = args[:cpus] if args.key?(:cpus) @enable_load_balancer = args[:enable_load_balancer] if args.key?(:enable_load_balancer) @image = args[:image] if args.key?(:image) @image_type = args[:image_type] if args.key?(:image_type) @labels = args[:labels] if args.key?(:labels) @memory_mb = args[:memory_mb] if args.key?(:memory_mb) @replicas = args[:replicas] if args.key?(:replicas) @taints = args[:taints] if args.key?(:taints) @vsphere_config = args[:vsphere_config] if args.key?(:vsphere_config) end |