Class: Google::Apis::GkeonpremV1::VmwarePlatformConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkeonpremV1::VmwarePlatformConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb
Overview
VmwarePlatformConfig represents configuration for the VMware platform.
Instance Attribute Summary collapse
-
#bundles ⇒ Array<Google::Apis::GkeonpremV1::VmwareBundleConfig>
Output only.
-
#platform_version ⇒ String
Output only.
-
#required_platform_version ⇒ String
Input only.
-
#status ⇒ Google::Apis::GkeonpremV1::ResourceStatus
ResourceStatus describes why a cluster or node pool has a certain status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmwarePlatformConfig
constructor
A new instance of VmwarePlatformConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmwarePlatformConfig
Returns a new instance of VmwarePlatformConfig.
5747 5748 5749 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bundles ⇒ Array<Google::Apis::GkeonpremV1::VmwareBundleConfig>
Output only. The list of bundles installed in the admin cluster.
Corresponds to the JSON property bundles
5726 5727 5728 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5726 def bundles @bundles end |
#platform_version ⇒ String
Output only. The platform version e.g. 1.13.2.
Corresponds to the JSON property platformVersion
5731 5732 5733 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5731 def platform_version @platform_version end |
#required_platform_version ⇒ String
Input only. The required platform version e.g. 1.13.1. If the current platform
version is lower than the target version, the platform version will be updated
to the target version. If the target version is not installed in the platform (
bundle versions), download the target version bundle.
Corresponds to the JSON property requiredPlatformVersion
5739 5740 5741 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5739 def required_platform_version @required_platform_version end |
#status ⇒ Google::Apis::GkeonpremV1::ResourceStatus
ResourceStatus describes why a cluster or node pool has a certain status. (e.g.
, ERROR or DEGRADED).
Corresponds to the JSON property status
5745 5746 5747 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5745 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5752 5753 5754 5755 5756 5757 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5752 def update!(**args) @bundles = args[:bundles] if args.key?(:bundles) @platform_version = args[:platform_version] if args.key?(:platform_version) @required_platform_version = args[:required_platform_version] if args.key?(:required_platform_version) @status = args[:status] if args.key?(:status) end |