Class: Google::Apis::GkeonpremV1::VmwareVersionInfo
- Inherits:
-
Object
- Object
- Google::Apis::GkeonpremV1::VmwareVersionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkeonprem_v1/classes.rb,
lib/google/apis/gkeonprem_v1/representations.rb,
lib/google/apis/gkeonprem_v1/representations.rb
Overview
Contains information about a specific Anthos on VMware version.
Instance Attribute Summary collapse
-
#dependencies ⇒ Array<Google::Apis::GkeonpremV1::UpgradeDependency>
The list of upgrade dependencies for this version.
-
#has_dependencies ⇒ Boolean
(also: #has_dependencies?)
If set, the cluster dependencies (e.g. the admin cluster, other user clusters managed by the same admin cluster) must be upgraded before this version can be installed or upgraded to.
-
#is_installed ⇒ Boolean
(also: #is_installed?)
If set, the version is installed in the admin cluster.
-
#version ⇒ String
Version number e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmwareVersionInfo
constructor
A new instance of VmwareVersionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmwareVersionInfo
Returns a new instance of VmwareVersionInfo.
5959 5960 5961 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5959 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dependencies ⇒ Array<Google::Apis::GkeonpremV1::UpgradeDependency>
The list of upgrade dependencies for this version.
Corresponds to the JSON property dependencies
5936 5937 5938 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5936 def dependencies @dependencies end |
#has_dependencies ⇒ Boolean Also known as: has_dependencies?
If set, the cluster dependencies (e.g. the admin cluster, other user clusters
managed by the same admin cluster) must be upgraded before this version can be
installed or upgraded to.
Corresponds to the JSON property hasDependencies
5943 5944 5945 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5943 def has_dependencies @has_dependencies end |
#is_installed ⇒ Boolean Also known as: is_installed?
If set, the version is installed in the admin cluster. Otherwise, the version
bundle must be downloaded and installed before a user cluster can be created
at or upgraded to this version.
Corresponds to the JSON property isInstalled
5951 5952 5953 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5951 def is_installed @is_installed end |
#version ⇒ String
Version number e.g. 1.13.1-gke.1000.
Corresponds to the JSON property version
5957 5958 5959 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5957 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5964 5965 5966 5967 5968 5969 |
# File 'lib/google/apis/gkeonprem_v1/classes.rb', line 5964 def update!(**args) @dependencies = args[:dependencies] if args.key?(:dependencies) @has_dependencies = args[:has_dependencies] if args.key?(:has_dependencies) @is_installed = args[:is_installed] if args.key?(:is_installed) @version = args[:version] if args.key?(:version) end |